==> bacula-docs-5.0.0.tar.bz2: bacula-docs-5.0.0/manuals/en/main/main/images.pl <==
# LaTeX2HTML 2008 (1.71)
# Associate images original text with physical files.


$key = q/includegraphics{bacula-logo.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="455" HEIGHT="99" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img5.png"
 ALT="\includegraphics{bacula-logo.eps}">|; 

$key = q/file_size*nb_file;MSF=1.6;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="130" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img10.png"
 ALT="$file\_size*nb\_file$">|; 

$key = q/includegraphics{error.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="32" HEIGHT="32" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img32.png"
 ALT="\includegraphics{error.eps}">|; 

$key = q/includegraphics{confirm.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="664" HEIGHT="139" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img37.png"
 ALT="\includegraphics{confirm.eps}">|; 

$key = q/includegraphics{different_time.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="1495" HEIGHT="772" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img15.png"
 ALT="\includegraphics{different_time.eps}">|; 

$key = q/<;MSF=1.6;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="16" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img1.png"
 ALT="$&lt;$">|; 

$key = q/includegraphics{access-is-denied.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="187" HEIGHT="125" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img33.png"
 ALT="\includegraphics{access-is-denied.eps}">|; 

$key = q/includegraphics{win32-pkg.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="501" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img24.png"
 ALT="\includegraphics{win32-pkg.eps}">|; 

$key = q/includegraphics{bacula-objects.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="573" HEIGHT="730" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img8.png"
 ALT="\includegraphics{bacula-objects.eps}">|; 

$key = q/includegraphics{Bacula-tray-monitor.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="832" HEIGHT="681" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img19.png"
 ALT="\includegraphics{Bacula-tray-monitor.eps}">|; 

$key = q/|;MSF=1.6;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="8" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img2.png"
 ALT="$\vert$">|; 

$key = q/includegraphics{menu.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="151" HEIGHT="115" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img30.png"
 ALT="\includegraphics{menu.eps}">|; 

$key = q/includegraphics[width=13cm]{bat12.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="588" HEIGHT="377" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img13.png"
 ALT="\includegraphics[width=13cm]{bat12.eps}">|; 

$key = q/includegraphics{view-only.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="423" HEIGHT="118" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img34.png"
 ALT="\includegraphics{view-only.eps}">|; 

$key = q/includegraphics{win32-installation-type.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="501" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img23.png"
 ALT="\includegraphics{win32-installation-type.eps}">|; 

$key = q/includegraphics{bacula-applications.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="573" HEIGHT="730" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img7.png"
 ALT="\includegraphics{bacula-applications.eps}">|; 

$key = q/includegraphics{win32-config.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="501" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img25.png"
 ALT="\includegraphics{win32-config.eps}">|; 

$key = q/>;MSF=1.6;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="16" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img3.png"
 ALT="$&gt;$">|; 

$key = q/includegraphics[width=13cm]{bat13.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="588" HEIGHT="386" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img14.png"
 ALT="\includegraphics[width=13cm]{bat13.eps}">|; 

$key = q/includegraphics[width=13cm]{bat11.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="588" HEIGHT="486" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img12.png"
 ALT="\includegraphics[width=13cm]{bat11.eps}">|; 

$key = q/nomath_inline}textregisterednomath_inline};MSF=1.6;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="19" HEIGHT="25" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img6.png"
 ALT="\textregistered">|; 

$key = q/includegraphics{properties-security.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="365" HEIGHT="439" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img35.png"
 ALT="\includegraphics{properties-security.eps}">|; 

$key = q/^{{normalsize{nomath_inline{textregisterednomath_inline{};MSF=1.6;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="23" HEIGHT="22" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img4.png"
 ALT="$^{\normalsize\textregistered }$">|; 

$key = q/<=;MSF=1.6;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="29" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img16.png"
 ALT="$&lt;=$">|; 

$key = q/includegraphics{win32-nsis.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="50" HEIGHT="48" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img21.png"
 ALT="\includegraphics{win32-nsis.eps}">|; 

$key = q/includegraphics{win32-welcome.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="501" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img22.png"
 ALT="\includegraphics{win32-welcome.eps}">|; 

$key = q/includegraphics{win32-finish.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="501" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img27.png"
 ALT="\includegraphics{win32-finish.eps}">|; 

$key = q/star;MSF=1.6;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="12" HEIGHT="13" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img17.png"
 ALT="$\star$">|; 

$key = q/includegraphics{properties-security-advanced-owner.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="483" HEIGHT="439" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img36.png"
 ALT="\includegraphics{properties-security-advanced-owner.eps}">|; 

$key = q/geq;MSF=1.6;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="16" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img18.png"
 ALT="$\geq$">|; 

$key = q/includegraphics{tray-icon.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="85" HEIGHT="28" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img29.png"
 ALT="\includegraphics{tray-icon.eps}">|; 

$key = q/includegraphics{win32-installing.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="501" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img26.png"
 ALT="\includegraphics{win32-installing.eps}">|; 

$key = q/includegraphics{flow.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="477" HEIGHT="368" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img9.png"
 ALT="\includegraphics{flow.eps}">|; 

$key = q/includegraphics{running.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="32" HEIGHT="32" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img31.png"
 ALT="\includegraphics{running.eps}">|; 

$key = q/includegraphics{idle.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="32" HEIGHT="32" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img28.png"
 ALT="\includegraphics{idle.eps}">|; 

$key = q/includegraphics[width=13cm]{bat-mediaview.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="588" HEIGHT="486" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img11.png"
 ALT="\includegraphics[width=13cm]{bat-mediaview.eps}">|; 

$key = q/includegraphics{Conf-Diagram.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="427" HEIGHT="508" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img20.png"
 ALT="\includegraphics{Conf-Diagram.eps}">|; 

1;

==> bacula-docs-5.0.2.tar.bz2: bacula-docs-5.0.2/manuals/en/main/main/images.pl <==
# LaTeX2HTML 2008 (1.71)
# Associate images original text with physical files.


$key = q/includegraphics{bacula-logo.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="455" HEIGHT="99" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img5.png"
 ALT="\includegraphics{bacula-logo.eps}">|; 

$key = q/includegraphics[width=13cm]{different_time.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="586" HEIGHT="304" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img15.png"
 ALT="\includegraphics[width=13cm]{different_time.eps}">|; 

$key = q/file_size*nb_file;MSF=1.6;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="130" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img10.png"
 ALT="$file\_size*nb\_file$">|; 

$key = q/includegraphics{error.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="32" HEIGHT="32" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img33.png"
 ALT="\includegraphics{error.eps}">|; 

$key = q/includegraphics{confirm.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="664" HEIGHT="139" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img38.png"
 ALT="\includegraphics{confirm.eps}">|; 

$key = q/includegraphics[width=13cm]{duplicate-real.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="589" HEIGHT="606" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img21.png"
 ALT="\includegraphics[width=13cm]{duplicate-real.eps}">|; 

$key = q/<;MSF=1.6;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="16" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img1.png"
 ALT="$&lt;$">|; 

$key = q/includegraphics{access-is-denied.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="187" HEIGHT="125" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img34.png"
 ALT="\includegraphics{access-is-denied.eps}">|; 

$key = q/includegraphics{win32-pkg.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="501" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img25.png"
 ALT="\includegraphics{win32-pkg.eps}">|; 

$key = q/includegraphics{bacula-objects.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="573" HEIGHT="730" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img8.png"
 ALT="\includegraphics{bacula-objects.eps}">|; 

$key = q/includegraphics{Bacula-tray-monitor.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="832" HEIGHT="681" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img19.png"
 ALT="\includegraphics{Bacula-tray-monitor.eps}">|; 

$key = q/|;MSF=1.6;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="8" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img2.png"
 ALT="$\vert$">|; 

$key = q/includegraphics{menu.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="151" HEIGHT="115" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img31.png"
 ALT="\includegraphics{menu.eps}">|; 

$key = q/includegraphics[width=13cm]{bat12.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="588" HEIGHT="377" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img13.png"
 ALT="\includegraphics[width=13cm]{bat12.eps}">|; 

$key = q/includegraphics{win32-installation-type.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="501" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img24.png"
 ALT="\includegraphics{win32-installation-type.eps}">|; 

$key = q/includegraphics{view-only.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="423" HEIGHT="118" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img35.png"
 ALT="\includegraphics{view-only.eps}">|; 

$key = q/includegraphics{bacula-applications.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="573" HEIGHT="730" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img7.png"
 ALT="\includegraphics{bacula-applications.eps}">|; 

$key = q/includegraphics{win32-config.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="501" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img26.png"
 ALT="\includegraphics{win32-config.eps}">|; 

$key = q/>;MSF=1.6;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="16" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img3.png"
 ALT="$&gt;$">|; 

$key = q/includegraphics[width=13cm]{bat13.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="588" HEIGHT="386" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img14.png"
 ALT="\includegraphics[width=13cm]{bat13.eps}">|; 

$key = q/includegraphics[width=13cm]{bat11.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="588" HEIGHT="486" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img12.png"
 ALT="\includegraphics[width=13cm]{bat11.eps}">|; 

$key = q/nomath_inline}textregisterednomath_inline};MSF=1.6;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="19" HEIGHT="25" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img6.png"
 ALT="\textregistered">|; 

$key = q/includegraphics{properties-security.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="365" HEIGHT="439" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img36.png"
 ALT="\includegraphics{properties-security.eps}">|; 

$key = q/^{{normalsize{nomath_inline{textregisterednomath_inline{};MSF=1.6;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="23" HEIGHT="22" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img4.png"
 ALT="$^{\normalsize\textregistered }$">|; 

$key = q/<=;MSF=1.6;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="29" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img16.png"
 ALT="$&lt;=$">|; 

$key = q/includegraphics{win32-nsis.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="50" HEIGHT="48" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img22.png"
 ALT="\includegraphics{win32-nsis.eps}">|; 

$key = q/includegraphics{win32-welcome.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="501" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img23.png"
 ALT="\includegraphics{win32-welcome.eps}">|; 

$key = q/includegraphics{win32-finish.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="501" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img28.png"
 ALT="\includegraphics{win32-finish.eps}">|; 

$key = q/star;MSF=1.6;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="12" HEIGHT="13" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img17.png"
 ALT="$\star$">|; 

$key = q/includegraphics{properties-security-advanced-owner.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="483" HEIGHT="439" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img37.png"
 ALT="\includegraphics{properties-security-advanced-owner.eps}">|; 

$key = q/geq;MSF=1.6;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="16" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
 SRC="|."$dir".q|img18.png"
 ALT="$\geq$">|; 

$key = q/includegraphics{tray-icon.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="85" HEIGHT="28" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img30.png"
 ALT="\includegraphics{tray-icon.eps}">|; 

$key = q/includegraphics{win32-installing.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="501" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img27.png"
 ALT="\includegraphics{win32-installing.eps}">|; 

$key = q/includegraphics{flow.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="477" HEIGHT="368" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img9.png"
 ALT="\includegraphics{flow.eps}">|; 

$key = q/includegraphics{running.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="32" HEIGHT="32" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img32.png"
 ALT="\includegraphics{running.eps}">|; 

$key = q/includegraphics{idle.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="32" HEIGHT="32" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img29.png"
 ALT="\includegraphics{idle.eps}">|; 

$key = q/includegraphics[width=13cm]{bat-mediaview.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="588" HEIGHT="486" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img11.png"
 ALT="\includegraphics[width=13cm]{bat-mediaview.eps}">|; 

$key = q/includegraphics{Conf-Diagram.eps};NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="427" HEIGHT="508" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img20.png"
 ALT="\includegraphics{Conf-Diagram.eps}">|; 

1;
